@@ -3,9 +3,20 @@ package FusionInventory::Agent::Task::Inventory::OS::Linux;
 use strict;
 use warnings;
 use English qw(-no_match_vars);
+use XML::Simple;
+
 
 our $runAfter = ["FusionInventory::Agent::Task::Inventory::OS::Generic"];
 
+# Get RedHat Network SystemId
+sub _getRHNSystemId {
+    my ($file) = @_;
+
+    return unless -f $file;
+    my $h = XMLin($file);
+    return eval {$h->{param}{value}{struct}{member}{system_id}{value}{string}};
+}
+
 sub isInventoryEnabled {
     return $OSNAME =~ /^linux$/;
 }
@@ -32,6 +43,7 @@ sub doInventory {
         OSNAME => "Linux",
         OSCOMMENTS => "Unknown Linux distribution",
         OSVERSION => $osversion,
+        WINPRODID => _getRHNSystemId('/etc/sysconfig/rhn/systemid') || '',
         LASTLOGGEDUSER => $lastloggeduser,
         DATELASTLOGGEDUSER => $datelastlog
     });
